==> haskell-resourcet-1.1.9-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.1.9
id: resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
key: resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
license: BSD3
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal
abi: 57ddf9a383fde857f6ca55aa4bfdbb02
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/resourcet-1.1.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/resourcet-1.1.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/resourcet-1.1.9
hs-libraries: HSresourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
depends:
    base-4.9.0.0 containers-0.5.7.1
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    mmorph-1.0.9-DmSwQqk5nLj7roLAcydGz
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resourcet-1.1.9-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.1.9
id: resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
key: resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
license: BSD3
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal
abi: 204d55b11867bc1e05af14de7c331f2f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/resourcet-1.1.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/resourcet-1.1.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/resourcet-1.1.9
hs-libraries: HSresourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
depends:
    base-4.9.0.0 containers-0.5.7.1
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    mmorph-1.0.9-DmSwQqk5nLj7roLAcydGz
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
